import java.io.*;
import java.util.*;

/**
 * Dynamic programming solution. The state is the number of problems chosen so far
 * and the two most difficult problems chosen. Process the problems in order of
 * difficulty. 
 *
 * @author Finn Lidbetter
 */

public class cc_finn {
  public static void main(String[] args) throws IOException {
    BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
    String[] s = br.readLine().split(" ");

    int n = Integer.parseInt(s[0]);
    int k = Integer.parseInt(s[1]);
    long[] problems = new long[n];
    for (int i=0; i<n; i++) {
      problems[i] = Integer.parseInt(br.readLine());
    }
    Arrays.sort(problems);
    
    // dp[i][j][l] is the number of Nice contests with i problems where problem
    // j and problem l are the two hardest problems in the contest so far.
    long[][][] dp = new long[k+1][n+1][n+1];
    // Setup the base cases.
    dp[0][0][0] = 1L;
    for (int i=0; i<n; i++) {
      dp[1][0][i] = 1L;
    }
    for (int p=1; p<=n; p++) {
      // Try adding problem p to the contest.

      int maxProblemsSoFar = p-1;
      if (maxProblemsSoFar>=k) {
        maxProblemsSoFar = k-1;
      }
      for (int i=1; i<=maxProblemsSoFar; i++) {
        for (int j=0; j<p; j++) {
          for (int l=j+1; l<p; l++) {
            if (j==0 || problems[p-1] <= problems[j-1] + problems[l-1]) {
              dp[i+1][l][p] += dp[i][j][l];
            }
          }
        }
      }
    }
    long sum = 0;
    for (int i=0; i<=n; i++) {
      for (int j=0; j<=n; j++) {
        sum += dp[k][i][j];
      }
    }
    System.out.println(sum);
  }
}
